@@ -25,21 +25,19 @@
 #include "avatargallery.h"
 
 #include <pwd.h>
+#include <unistd.h>
 
 #include <QMenu>
 #include <QToolButton>
-#include <QDesktopServices>
+#include <QStandardPaths>
+#include <QImageReader>
+#include <QFontDatabase>
+#include <QFileDialog>
 
 #include "user_manager_debug.h"
-#include <KImageIO>
-#include <KFileDialog>
-#include <KImageFilePreview>
-#include <KIO/Job>
-#include <kio/copyjob.h>
-#include <KTemporaryFile>
-#include <KGlobalSettings>
+#include <KJob>
+#include <KIO/CopyJob>
 #include <KIconLoader>
-#include <QFontDatabase>
 
 AccountInfo::AccountInfo(AccountModel* model, QWidget* parent, Qt::WindowFlags f)
  : QWidget(parent, f)
@@ -60,11 +58,6 @@ AccountInfo::AccountInfo(AccountModel* model, QWidget* parent, Qt::WindowFlags f
     connect(m_passwordEdit, SIGNAL(focused()), SLOT(changePassword()));
     connect(m_passwordEdit, SIGNAL(textEdited(QString)), SLOT(changePassword()));
 
-    //automaticLogin only sets a flag in AccountsService, which isn't supported by anything else
-    //so hide it until the situation is different
-    m_info->automaticLogin->setVisible(false);
-    m_info->automaticLoginLabel->setVisible(false);
-
     connect(m_model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(dataChanged(QModelIndex)));
     m_info->face->setPopupMode(QToolButton::InstantPopup);
     QMenu* menu = new QMenu(this);
@@ -181,17 +174,17 @@ bool AccountInfo::save()
     }
     if (m_infoToSave.contains(AccountModel::Face)) {
         const QString path = m_infoToSave[AccountModel::Face].toString();
-        QString faceFile = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
+        QString faceFile = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
         faceFile.append(QLatin1String("/.face"));
 
         QFile::remove(faceFile);
         KIO::CopyJob* moveJob = KIO::move(QUrl::fromLocalFile(path), QUrl::fromLocalFile(faceFile), KIO::HideProgressInfo);
         connect(moveJob, SIGNAL(finished(KJob*)), SLOT(avatarModelChanged(KJob*)));
         moveJob->setUiDelegate(0);
-        // Run it synchronously to be sure the job ends before the KCM gets deleted.
-        moveJob->exec();
+        moveJob->setUiDelegateExtension(0);
+        moveJob->start();
 
-        QString faceFile2 = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
+        QString faceFile2 = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
         faceFile2.append(QLatin1String("/.face.icon"));
         QFile::remove(faceFile2);
         QFile::link(faceFile, faceFile2);
@@ -407,22 +400,29 @@ void AccountInfo::openGallery()
     job->start();
 }
 
+QStringList AccountInfo::imageFormats() const
+{
+    QStringList result;
+    for(const QByteArray b: QImageReader::supportedMimeTypes()) {
+        if (! b.isEmpty())
+            result.append(QString(b));
+    }
+    return result;
+}
+
 void AccountInfo::openAvatarSlot()
 {
-    KFileDialog dlg(QUrl::fromLocalFile(QDir::homePath()), KImageIO::pattern(KImageIO::Reading), this);
+    QFileDialog dlg(this, i18nc("@title:window", "Choose Image"), QDir::homePath());
 
-    dlg.setOperationMode(KFileDialog::Opening);
-    dlg.setWindowTitle(i18nc("@title:window", "Choose Image"));
-    dlg.setMode(KFile::File);
-
-    KImageFilePreview *imagePreviewer = new KImageFilePreview(&dlg);
-    dlg.setPreviewWidget(imagePreviewer);
+    dlg.setMimeTypeFilters(imageFormats());
+    dlg.setAcceptMode(QFileDialog::AcceptOpen);
+    dlg.setFileMode(QFileDialog::ExistingFile);
 
     if (dlg.exec() != QDialog::Accepted) {
         return;
     }
 
-    QUrl url = QUrl::fromLocalFile(dlg.selectedFile());
+    QUrl url = QUrl::fromLocalFile(dlg.selectedFiles().first());
     CreateAvatarJob *job = new CreateAvatarJob(this);
     connect(job, SIGNAL(finished(KJob*)), SLOT(avatarCreated(KJob*)));
     job->setUrl(url);
@@ -431,11 +431,13 @@ void AccountInfo::openAvatarSlot()
 
 void AccountInfo::avatarCreated(KJob* job)
 {
-    qCDebug(USER_MANAGER_LOG) << "Avatar created";
-    CreateAvatarJob *aJob = qobject_cast<CreateAvatarJob*>(job);
-    m_info->face->setIcon(QIcon(aJob->avatarPath()));
-    m_infoToSave.insert(AccountModel::Face, aJob->avatarPath());
-    Q_EMIT changed(true);
+    if (! job->error()) {
+        qCDebug(USER_MANAGER_LOG) << "Avatar created";
+        CreateAvatarJob *aJob = qobject_cast<CreateAvatarJob*>(job);
+        m_info->face->setIcon(QIcon(aJob->avatarPath()));
+        m_infoToSave.insert(AccountModel::Face, aJob->avatarPath());
+        Q_EMIT changed(true);
+    }
 }
 
 void AccountInfo::avatarModelChanged(KJob* job)
